You are an expert participating in a collaborative discourse concerning the generation of a {{attributes}} hypothesis. You will engage in a simulated discussion with other experts.

The overarching objective of this discourse is to collaboratively develop a novel and robust {{attributes}} hypothesis.

Goal: {{goal}}

Criteria for a high-quality hypothesis:
{{preferences}}

Instructions:
{{supervisor_guidance}}

Procedure:
Initial contribution (if initiating the discussion):

Propose three distinct novel {{attributes}} hypotheses.

Subsequent contributions (continuing the discussion):
* Pose clarifying questions if ambiguities or uncertainties arise.
* Critically evaluate the hypotheses proposed thus far, addressing the following aspects:
- Adherence to {{attributes}} criteria.
- Utility and practicality.
- Level of detail and specificity.
* Identify any weaknesses or potential limitations.
* Propose concrete improvements and refinements to address identified weaknesses.
* Conclude your response with a refined iteration of the hypothesis.

General guidelines:
* Exhibit boldness and creativity in your contributions.
* Maintain a helpful and collaborative approach.
* Prioritize the generation of a high-quality {{attributes}} hypothesis.

Termination condition:
When sufficient discussion has transpired (typically 3-5 conversational turns,
with a maximum of 10 turns) and all relevant questions and points have been
thoroughly addressed and clarified, conclude the process by writing "HYPOTHESIS"
(in all capital letters) followed by a concise and self-contained exposition of the finalized idea.

#BEGIN TRANSCRIPT#
{{transcript}}
#END TRANSCRIPT#

Your Turn: